Learn R Programming

qtlmt (version 0.1-1)

mtcmim: MTCMIM

Description

Multiple-trait composite multiple-interval mapping.

Usage

mtcmim(y, mpos, mdat, x, xid, dists, a, b, sigma, qtl=NULL,
   eps=NULL, win=Inf, range=0, pp=1, len=2, init=1,
   iter=2500,tol=1e-8)

Arguments

y
n by p matrix, whose columns are dependent variables.
mpos
data frame (id=marker index, ch=chromosome id, m=marker index on the chromosome, dist=genetic position in cM on the chromosome). Chromosome id should be an integer.
mdat
matrix of n rows; marker genotypes (1 or 0). Columns should correspond to markers in the order.
x
covariates; n by m numerical matrix.
xid
list of length p, xid[[j]] specifies columns of x as covariates for y[,j] .
dists
data frame (ch=chromosome id, mid=marker index, d=genetic position in cM on the chromosome); specifies initial QTL locations. Chromosome id should be an integer.
a
initial covariate effects including intercepts (if given).
b
initial QTL effects (if given).
sigma
initial residual variance-covariance (if given).
qtl
list of length p (if given); qtl[[j]] specifies qtls for y[,j], which are defined by rows of dists.
eps
data frame (y=which trait,q1=QTL one,q2=QTL two) (if not NULL); specifies epistatic terms.
win
window width of search around existing QTL. Ignored if range=0.
range
search range: genome-wide (0), the same chromosomes (-1).
pp
mapping population: BC-1, RIL-selfing-2, RIL-brother-sister-mating-3.
len
step length in search.
init
whether a, b and sigma are used as initial values.
iter
maximum number of iterations in a numerical process to estimate model parameters.
tol
convergence tolerance.

Value

  • a list with the following components:
  • loglik:log-likelihood of the final model
  • a:covariate effects
  • b:QTL effects
  • sigma:residual variance-covariance
  • qtl:QTL for each trait
  • eps:epistatic terms
  • dists:QTL locations

Examples

Run this code
data(etrait)
qtl<- vector("list",16); qtl[[1]]<- c(1,2)
eps<- data.frame(y=1,q1=1,q2=2)
dists<- dists[c(4,11),]
x<- mdat - 3/2
o<- mtcmim(traits,mpos,mdat,x,xid,dists,
   qtl=qtl,eps=eps,win=5,range=-1,pp=2,len=1)

Run the code above in your browser using DataLab