Learn R Programming

qtlmt (version 0.1-3)

sureEps: Epistasis in a SURE model

Description

Look for epistasis between existing QTL in a model via model selection.

Usage

sureEps(y, x, v, k, direction=c("both","backward","forward"),
   iter=250, max.terms=200, steps=1000, tol=1e-8)

Arguments

y
a n by p matrix, whose columns are dependent variables.
x
a n by m matrix, whose columns are predictor variables
v
a list; v[[j]] indicates which x's in the model for y[,j], between which possible epistasis is looked for.
k
penalty, 0 if missing or
direction
forward selection, backward elimination or stepwise.
iter
maximum number of iterations in a numerical process to estimate model parameters.
max.terms
maximum number of terms in the final model.
steps
maximum number of search steps.
tol
convergence tolerance.

Value

  • associated traits, epistatic markers and p-values

See Also

surStep

Examples

Run this code
data(etrait)
x<- as.matrix(3/2-mdat)
y<- as.matrix(traits)[,1:3]
v<- list()
upper<- list()
for(k in 1:ncol(y)){
   v[[k]]<- numeric(0)
   upper[[k]]<- 1:ncol(x)
}
o<- surStep(y, x, v=v, upper=upper, k=19, direction="both",
   iter=250, max.terms=250, steps=2000, tol=1e-6)
neps<- 6 # suppose there are 6 possible epistatic effects
oeps<- sureEps(y, x, o$v, k=qchisq(1-0.05/neps,1), direction="backward",
  iter=250, max.terms=200, steps=1000, tol=1e-8)

Run the code above in your browser using DataLab