Usage
mtcmim(y, mpos, mdat, x, xid, dists, a, b, sigma, qtl=NULL,
eps=NULL, win=Inf, range=0, pp=1, len=2, init=1,
iter=2500,tol=1e-8)
Arguments
y
a n by p matrix, whose columns are dependent variables.
mpos
a data frame (id=marker index, ch=chromosome id, m=marker index on the chromosome, dist=genetic position in cM on the chromosome). Chromosome id should be an integer.
mdat
a matrix of n rows; marker genotypes (1 or 0). Columns should correspond to markers in the order.
x
covariates; n by m numerical matrix.
xid
a list of length p, xid[[j]] specifies columns of x as covariates for y[,j] .
dists
a data frame (ch=chromosome id, mid=marker index, d=genetic position in cM on the chromosome); specifies initial QTL locations. Chromosome id should be an integer.
a
initial covariate effects including intercepts (if given).
b
initial QTL effects (if given).
sigma
initial residual variance-covariance (if given).
qtl
a list of length p (if given); qtl[[j]] specifies qtls for y[,j], which are defined by rows of dists.
eps
a data frame (y=which trait,q1=QTL one,q2=QTL two) (if not NULL); specifies epistatic terms.
win
window width of search around existing QTL. Ignored if range=0.
range
search range: genome-wide (0), the same chromosomes (-1).
pp
mapping population: BC-1, RIL-selfing-2, RIL-brother-sister-mating-3.
len
step length in search.
init
whether a, b and sigma are used as initial values.
iter
maximum number of iterations in a numerical process to estimate model parameters.
tol
convergence tolerance.