Learn R Programming

qtlmt (version 0.1-3)

sureEst: SURE model parameter estimation

Description

Estimate parameters in a SURE model.

Usage

sureEst(y, x, v, sigma, iter=250, tol=1e-8)

Arguments

y
a n by p matrix, whose columns are dependent variables.
x
a n by m matrix, whose columns are predictor variables to select from.
v
a list; v[[j]] indicates which x's in the model for y[,j].
sigma
residual variance-covarance matrix (if given).
iter
maximum number of iterations in a numerical process to estimate model parameters.
tol
convergence tolerance.

Value

  • a list with the following components:
  • loglik:log-likelihood of the model
  • b:estimates of model coefficients
  • sigma:estimated residual variance-covariance

Examples

Run this code
data(etrait)
x<- as.matrix(3/2-mdat)
y<- as.matrix(traits)[,1:3]
v<- list(c(1,25,50),numeric(0),3)
o<- sureEst(y, x, v=v, iter=250, tol=1e-8)

Run the code above in your browser using DataLab